
from volworld_aws_api_common.test.behave.selenium_utils import get_element_by_dom_id


def assert_input_elm_enabled_by_dom_id(c, ids: list, enabled: bool):
    elm = get_element_by_dom_id(c, ids)
    # print(f"innerHtml = {elm.get_attribute('outerHTML')}")
    disabled = elm.get_attribute("disabled")
    if enabled:
        assert disabled is None
    else:
        assert enabled == (not elm.get_attribute("disabled")), \
            f"enabled = {enabled} != {elm.is_enabled()} = elm = {elm.get_attribute('disabled')} = disabled"


def assert_input_elm_selected_by_dom_id(c, ids: list):
    elm = get_element_by_dom_id(c, ids)
    assert elm.is_selected()


def assert_input_elm_not_selected_by_dom_id(c, ids: list):
    elm = get_element_by_dom_id(c, ids)
    assert not elm.is_selected()


from behave import *
from volworld_aws_api_common.test.behave.selenium_utils import w__get_element_by_shown_dom_id, w__click_element_by_dom_id
from volworld_aws_api_common.api.AA import AA


@then('[save button] is disabled')
def then_the_save_button_is_disabled(c):
    elm = w__get_element_by_shown_dom_id(c, [AA.Save, AA.Button])
    assert not elm.is_enabled()


@then('[save button] is enabled')
def then_the_save_button_is_enabled(c):
    elm = w__get_element_by_shown_dom_id(c, [AA.Save, AA.Button])
    assert elm.is_enabled()


@when('{user} click on [save button]')
def when_click_on_save_button(c, user: str):
    w__click_element_by_dom_id(c, [AA.Save, AA.Button])


@then('[ok button] is disabled')
def then_the_ok_button_is_disabled(context):
    elm = w__get_element_by_shown_dom_id(context, [AA.Ok, AA.Button])
    assert not elm.is_enabled()


@then('[ok button] is enabled')
def then_the_ok_button_is_enabled(context):
    elm = w__get_element_by_shown_dom_id(context, [AA.Ok, AA.Button])
    assert elm.is_enabled()


@when('{user} click on [ok button]')
def when_click_on_ok_button(context, user: str):
    w__click_element_by_dom_id(context, [AA.Ok, AA.Button])


from volworld_aws_api_common.api.AA import AA, AAList
from volworld_aws_api_common.api.url import authUrl
from volworld_aws_api_common.test.aws.ATestRequest import ATestRequest
from volworld_aws_api_common.test.request import post_request
from volworld_aws_api_common.test.aws.request.post__signup import act__signup
from volworld_aws_api_common.api.enum.HttpStatus import HttpStatus

from volworld_aws_api_common.api.Aws import Aws
from volworld_aws_api_common.test.aws.request.request_util import response_to_dict


def post__login(
        name: str, pw: str,
        req: ATestRequest,
        # status_code: int = -1
):
    resp_json, resp = post_request(
        authUrl.do_login_url(), {
            AA.Name: name,
            AA.Password: pw,
        }, req, AAList
    )

    return response_to_dict(resp_json, resp)


def act__login(name: str = None, pw: str = None) -> dict:
    resp = post__login(name, pw, ATestRequest(True))
    if resp[AA.Data] is not None:
        assert resp[AA.HttpStatus] == HttpStatus.Ok_200.value
        resp[AA.Token] = resp[AA.Data][AA.Token]
    else:
        assert AA.___Error___ in resp
    return resp


def act__signup_login(name: str = None, pw: str = None) -> dict:
    signup = act__signup(name, pw)
    resp = post__login(signup[AA.Name], signup[AA.Password], ATestRequest(True))
    assert resp[AA.HttpStatus] == HttpStatus.Ok_200.value
    return {
        AA.Name: signup[AA.Name],
        AA.Password: signup[AA.Password],
        AA.Data: resp[AA.Data],
        AA.Token: resp[AA.Data][AA.Token]
    }



import time

from selenium.webdriver.remote.webelement import WebElement
from volworld_common.api.CA import CA

from volworld_aws_api_common.api.dom_id import dom_id
from volworld_aws_api_common.test.behave.selenium_utils import w__click_element_by_dom_id, get_element_by_dom_id


def waiting_for_drawer_animation():
    time.sleep(0.2)


def click_to_open_list_nav_drawer(c, tar_id: str, prefix=None) -> WebElement:
    if prefix is None:
        prefix = list()
    elm = w__click_element_by_dom_id(c, prefix + [CA.List, CA.Navigator, CA.Button, tar_id])

    waiting_for_drawer_animation()
    return elm


def click_to_close_list_nav_drawer(c, tar_id: str, prefix=None) -> WebElement:
    if prefix is None:
        prefix = list()
    dom_id_list = prefix + [CA.Drawer, tar_id, CA.Header, CA.Close]
    elm = get_element_by_dom_id(c, dom_id_list)
    if elm is None:
        print(f"Can NOT find close button of id=[{dom_id(dom_id_list)}]")
        return None

    elm = w__click_element_by_dom_id(c, dom_id_list)

    waiting_for_drawer_animation()
    return elm


from behave import *


@when('clear browser local storage')
def when_clear_local_storage(c):
    c.browser.execute_script("window.localStorage.clear();")


@when('refresh browser')
def when_refresh_browser(c):
    c.browser.refresh()



from typing import Final

# ====== ContextA: Attribute ======


class ACotA:

    LoginUser: Final[str] = "LoginUser"

    MockScenario: Final[str] = "MockScenario"

    TargetPage: Final[str] = "TargetPage"

    UserName: Final[str] = "UserName"
    UserPassword: Final[str] = "UserPassword"

